@@ -87,7 +87,7 @@ Usage::
 """
 from typing import Sequence
 
-from botocore.waiter import Waiter as Boto3Waiter
+from botocore.waiter import Waiter
 
 from .type_defs import FilterTypeDef, WaiterConfigTypeDef
 
@@ -129,7 +129,7 @@ __all__ = (
 )
 
 
-class BundleTaskCompleteWaiter(Boto3Waiter):
+class BundleTaskCompleteWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.BundleTaskComplete)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#bundletaskcompletewaiter)
@@ -149,7 +149,7 @@ class BundleTaskCompleteWaiter(Boto3Waiter):
         """
 
 
-class ConversionTaskCancelledWaiter(Boto3Waiter):
+class ConversionTaskCancelledWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ConversionTaskCancelled)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#conversiontaskcancelledwaiter)
@@ -168,7 +168,7 @@ class ConversionTaskCancelledWaiter(Boto3Waiter):
         """
 
 
-class ConversionTaskCompletedWaiter(Boto3Waiter):
+class ConversionTaskCompletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ConversionTaskCompleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#conversiontaskcompletedwaiter)
@@ -187,7 +187,7 @@ class ConversionTaskCompletedWaiter(Boto3Waiter):
         """
 
 
-class ConversionTaskDeletedWaiter(Boto3Waiter):
+class ConversionTaskDeletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ConversionTaskDeleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#conversiontaskdeletedwaiter)
@@ -206,7 +206,7 @@ class ConversionTaskDeletedWaiter(Boto3Waiter):
         """
 
 
-class CustomerGatewayAvailableWaiter(Boto3Waiter):
+class CustomerGatewayAvailableWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.CustomerGatewayAvailable)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#customergatewayavailablewaiter)
@@ -226,7 +226,7 @@ class CustomerGatewayAvailableWaiter(Boto3Waiter):
         """
 
 
-class ExportTaskCancelledWaiter(Boto3Waiter):
+class ExportTaskCancelledWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ExportTaskCancelled)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#exporttaskcancelledwaiter)
@@ -245,7 +245,7 @@ class ExportTaskCancelledWaiter(Boto3Waiter):
         """
 
 
-class ExportTaskCompletedWaiter(Boto3Waiter):
+class ExportTaskCompletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ExportTaskCompleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#exporttaskcompletedwaiter)
@@ -264,7 +264,7 @@ class ExportTaskCompletedWaiter(Boto3Waiter):
         """
 
 
-class ImageAvailableWaiter(Boto3Waiter):
+class ImageAvailableWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ImageAvailable)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#imageavailablewaiter)
@@ -287,7 +287,7 @@ class ImageAvailableWaiter(Boto3Waiter):
         """
 
 
-class ImageExistsWaiter(Boto3Waiter):
+class ImageExistsWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.ImageExists)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#imageexistswaiter)
@@ -310,7 +310,7 @@ class ImageExistsWaiter(Boto3Waiter):
         """
 
 
-class InstanceExistsWaiter(Boto3Waiter):
+class InstanceExistsWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.InstanceExists)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#instanceexistswaiter)
@@ -332,7 +332,7 @@ class InstanceExistsWaiter(Boto3Waiter):
         """
 
 
-class InstanceRunningWaiter(Boto3Waiter):
+class InstanceRunningWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.InstanceRunning)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#instancerunningwaiter)
@@ -354,7 +354,7 @@ class InstanceRunningWaiter(Boto3Waiter):
         """
 
 
-class InstanceStatusOkWaiter(Boto3Waiter):
+class InstanceStatusOkWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.InstanceStatusOk)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#instancestatusokwaiter)
@@ -377,7 +377,7 @@ class InstanceStatusOkWaiter(Boto3Waiter):
         """
 
 
-class InstanceStoppedWaiter(Boto3Waiter):
+class InstanceStoppedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.InstanceStopped)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#instancestoppedwaiter)
@@ -399,7 +399,7 @@ class InstanceStoppedWaiter(Boto3Waiter):
         """
 
 
-class InstanceTerminatedWaiter(Boto3Waiter):
+class InstanceTerminatedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.InstanceTerminated)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#instanceterminatedwaiter)
@@ -421,7 +421,7 @@ class InstanceTerminatedWaiter(Boto3Waiter):
         """
 
 
-class InternetGatewayExistsWaiter(Boto3Waiter):
+class InternetGatewayExistsWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.InternetGatewayExists)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#internetgatewayexistswaiter)
@@ -443,7 +443,7 @@ class InternetGatewayExistsWaiter(Boto3Waiter):
         """
 
 
-class KeyPairExistsWaiter(Boto3Waiter):
+class KeyPairExistsWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.KeyPairExists)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#keypairexistswaiter)
@@ -465,7 +465,7 @@ class KeyPairExistsWaiter(Boto3Waiter):
         """
 
 
-class NatGatewayAvailableWaiter(Boto3Waiter):
+class NatGatewayAvailableWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.NatGatewayAvailable)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#natgatewayavailablewaiter)
@@ -487,7 +487,7 @@ class NatGatewayAvailableWaiter(Boto3Waiter):
         """
 
 
-class NatGatewayDeletedWaiter(Boto3Waiter):
+class NatGatewayDeletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.NatGatewayDeleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#natgatewaydeletedwaiter)
@@ -509,7 +509,7 @@ class NatGatewayDeletedWaiter(Boto3Waiter):
         """
 
 
-class NetworkInterfaceAvailableWaiter(Boto3Waiter):
+class NetworkInterfaceAvailableWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.NetworkInterfaceAvailable)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#networkinterfaceavailablewaiter)
@@ -531,7 +531,7 @@ class NetworkInterfaceAvailableWaiter(Boto3Waiter):
         """
 
 
-class PasswordDataAvailableWaiter(Boto3Waiter):
+class PasswordDataAvailableWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.PasswordDataAvailable)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#passworddataavailablewaiter)
@@ -546,7 +546,7 @@ class PasswordDataAvailableWaiter(Boto3Waiter):
         """
 
 
-class SecurityGroupExistsWaiter(Boto3Waiter):
+class SecurityGroupExistsWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SecurityGroupExists)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#securitygroupexistswaiter)
@@ -569,7 +569,7 @@ class SecurityGroupExistsWaiter(Boto3Waiter):
         """
 
 
-class SnapshotCompletedWaiter(Boto3Waiter):
+class SnapshotCompletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SnapshotCompleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#snapshotcompletedwaiter)
@@ -593,7 +593,7 @@ class SnapshotCompletedWaiter(Boto3Waiter):
         """
 
 
-class SpotInstanceRequestFulfilledWaiter(Boto3Waiter):
+class SpotInstanceRequestFulfilledWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SpotInstanceRequestFulfilled)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#spotinstancerequestfulfilledwaiter)
@@ -615,7 +615,7 @@ class SpotInstanceRequestFulfilledWaiter(Boto3Waiter):
         """
 
 
-class SubnetAvailableWaiter(Boto3Waiter):
+class SubnetAvailableWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SubnetAvailable)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#subnetavailablewaiter)
@@ -637,7 +637,7 @@ class SubnetAvailableWaiter(Boto3Waiter):
         """
 
 
-class SystemStatusOkWaiter(Boto3Waiter):
+class SystemStatusOkWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SystemStatusOk)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#systemstatusokwaiter)
@@ -660,7 +660,7 @@ class SystemStatusOkWaiter(Boto3Waiter):
         """
 
 
-class VolumeAvailableWaiter(Boto3Waiter):
+class VolumeAvailableWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VolumeAvailable)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#volumeavailablewaiter)
@@ -682,7 +682,7 @@ class VolumeAvailableWaiter(Boto3Waiter):
         """
 
 
-class VolumeDeletedWaiter(Boto3Waiter):
+class VolumeDeletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VolumeDeleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#volumedeletedwaiter)
@@ -704,7 +704,7 @@ class VolumeDeletedWaiter(Boto3Waiter):
         """
 
 
-class VolumeInUseWaiter(Boto3Waiter):
+class VolumeInUseWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VolumeInUse)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#volumeinusewaiter)
@@ -726,7 +726,7 @@ class VolumeInUseWaiter(Boto3Waiter):
         """
 
 
-class VpcAvailableWaiter(Boto3Waiter):
+class VpcAvailableWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VpcAvailable)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#vpcavailablewaiter)
@@ -748,7 +748,7 @@ class VpcAvailableWaiter(Boto3Waiter):
         """
 
 
-class VpcExistsWaiter(Boto3Waiter):
+class VpcExistsWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VpcExists)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#vpcexistswaiter)
@@ -770,7 +770,7 @@ class VpcExistsWaiter(Boto3Waiter):
         """
 
 
-class VpcPeeringConnectionDeletedWaiter(Boto3Waiter):
+class VpcPeeringConnectionDeletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VpcPeeringConnectionDeleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#vpcpeeringconnectiondeletedwaiter)
@@ -792,7 +792,7 @@ class VpcPeeringConnectionDeletedWaiter(Boto3Waiter):
         """
 
 
-class VpcPeeringConnectionExistsWaiter(Boto3Waiter):
+class VpcPeeringConnectionExistsWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VpcPeeringConnectionExists)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#vpcpeeringconnectionexistswaiter)
@@ -814,7 +814,7 @@ class VpcPeeringConnectionExistsWaiter(Boto3Waiter):
         """
 
 
-class VpnConnectionAvailableWaiter(Boto3Waiter):
+class VpnConnectionAvailableWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VpnConnectionAvailable)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#vpnconnectionavailablewaiter)
@@ -834,7 +834,7 @@ class VpnConnectionAvailableWaiter(Boto3Waiter):
         """
 
 
-class VpnConnectionDeletedWaiter(Boto3Waiter):
+class VpnConnectionDeletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.VpnConnectionDeleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#vpnconnectiondeletedwaiter)
